require 'spec_helper'

class Base
  extend SerializeAccessors
end

class Person < Base
  attr_accessor :contact
  serialize_accessors :contact, :first_name, :last_name, :email
end

describe SerializeAccessors do
  it "defines method to call" do
    Base.should respond_to :serialize_accessors
  end

  describe "person" do
    before(:each) { @person = Person.new }

    it "creates accessor methods" do
      @person.should respond_to :first_name, :last_name, :email
    end

    it "makes serialized field nil if there is no value" do
      @person.contact.should be_nil
    end

    it "makes serialized field a hash if it has a value" do
      @person.first_name = "Joe"
      @person.contact.should be_a Hash
    end

    it "gets nil if attribute doesnt exist on serialized field" do
      @person.email.should be_nil
    end

    it "gets value of attribute through getter" do
      @person.contact = { :first_name => "Joe", :last_name => "Smith" }
      @person.first_name.should eql "Joe"
      @person.last_name.should eql "Smith"
    end

    it "sets value of attribute through setter" do
      @person.first_name = "Joe"
      @person.contact[:first_name].should eql "Joe"

      @person.last_name = "Smith"
      @person.contact[:last_name].should eql "Smith"
    end
  end
end